//+------------------------------------------------------------------+
//|                                               tf-ea-s1-t1-m4.mq5 |
//|                             Thorsten Fischer Copyright 2019-2020 |
//|                                         https://mql5.tfsystem.de |
//+------------------------------------------------------------------+
#property copyright "Thorsten Fischer Copyright 2019-2020"
#property link      "https://mql5.tfsystem.de"
#property version   "1.00"
//+------------------------------------------------------------------+
//| Include                                                          |
//+------------------------------------------------------------------+
#include <Expert\Expert.mqh>
//--- available signals
#include <Expert\Signal\SignalITF.mqh>
//--- available trailing
#include <Expert\Trailing\TrailingFixedPips.mqh>
//--- available money management
#include <Expert\Money\MoneyNone.mqh>
//+------------------------------------------------------------------+
//| Inputs                                                           |
//+------------------------------------------------------------------+
//--- inputs for expert
input string Expert_Title                  ="tf-ea-s1-t1-m4"; // Document name
ulong        Expert_MagicNumber            =11120;            //
bool         Expert_EveryTick              =false;            //
//--- inputs for main signal
input int    Signal_ThresholdOpen          =10;               // Signal threshold value to open [0...100]
input int    Signal_ThresholdClose         =10;               // Signal threshold value to close [0...100]
input double Signal_PriceLevel             =0.0;              // Price level to execute a deal
input double Signal_StopLevel              =50.0;             // Stop Loss level (in points)
input double Signal_TakeLevel              =50.0;             // Take Profit level (in points)
input int    Signal_Expiration             =4;                // Expiration of pending orders (in bars)
input int    Signal_ITF_GoodHourOfDay      =-1;               // IntradayTimeFilter(-1,0,-1,...) Good hour
input int    Signal_ITF_BadHoursOfDay      =0;                // IntradayTimeFilter(-1,0,-1,...) Bad hours (bit-map)
input int    Signal_ITF_GoodDayOfWeek      =-1;               // IntradayTimeFilter(-1,0,-1,...) Good day of week
input int    Signal_ITF_BadDaysOfWeek      =0;                // IntradayTimeFilter(-1,0,-1,...) Bad days of week (bit-map)
input double Signal_ITF_Weight             =1.0;              // IntradayTimeFilter(-1,0,-1,...) Weight [0...1.0]
//--- inputs for trailing
input int    Trailing_FixedPips_StopLevel  =30;               // Stop Loss trailing level (in points)
input int    Trailing_FixedPips_ProfitLevel=50;               // Take Profit trailing level (in points)
//+------------------------------------------------------------------+
//| Global expert object                                             |
//+------------------------------------------------------------------+
CExpert ExtExpert;
//+------------------------------------------------------------------+
//| Initialization function of the expert                            |
//+------------------------------------------------------------------+
int OnInit()
{
//--- Initializing expert
   if(!ExtExpert.Init(Symbol(),Period(),Expert_EveryTick,Expert_MagicNumber))
      {
         //--- failed
         printf(__FUNCTION__+": error initializing expert");
         ExtExpert.Deinit();
         return(INIT_FAILED);
      }
//--- Creating signal
   CExpertSignal *signal=new CExpertSignal;
   if(signal==NULL)
      {
         //--- failed
         printf(__FUNCTION__+": error creating signal");
         ExtExpert.Deinit();
         return(INIT_FAILED);
      }
//---
   ExtExpert.InitSignal(signal);
   signal.ThresholdOpen(Signal_ThresholdOpen);
   signal.ThresholdClose(Signal_ThresholdClose);
   signal.PriceLevel(Signal_PriceLevel);
   signal.StopLevel(Signal_StopLevel);
   signal.TakeLevel(Signal_TakeLevel);
   signal.Expiration(Signal_Expiration);
//--- Creating filter CSignalITF
   CSignalITF *filter0=new CSignalITF;
   if(filter0==NULL)
      {
         //--- failed
         printf(__FUNCTION__+": error creating filter0");
         ExtExpert.Deinit();
         return(INIT_FAILED);
      }
   signal.AddFilter(filter0);
//--- Set filter parameters
   filter0.GoodHourOfDay(Signal_ITF_GoodHourOfDay);
   filter0.BadHoursOfDay(Signal_ITF_BadHoursOfDay);
   filter0.GoodDayOfWeek(Signal_ITF_GoodDayOfWeek);
   filter0.BadDaysOfWeek(Signal_ITF_BadDaysOfWeek);
   filter0.Weight(Signal_ITF_Weight);
//--- Creation of trailing object
   CTrailingFixedPips *trailing=new CTrailingFixedPips;
   if(trailing==NULL)
      {
         //--- failed
         printf(__FUNCTION__+": error creating trailing");
         ExtExpert.Deinit();
         return(INIT_FAILED);
      }
//--- Add trailing to expert (will be deleted automatically))
   if(!ExtExpert.InitTrailing(trailing))
      {
         //--- failed
         printf(__FUNCTION__+": error initializing trailing");
         ExtExpert.Deinit();
         return(INIT_FAILED);
      }
//--- Set trailing parameters
   trailing.StopLevel(Trailing_FixedPips_StopLevel);
   trailing.ProfitLevel(Trailing_FixedPips_ProfitLevel);
//--- Creation of money object
   CMoneyNone *money=new CMoneyNone;
   if(money==NULL)
      {
         //--- failed
         printf(__FUNCTION__+": error creating money");
         ExtExpert.Deinit();
         return(INIT_FAILED);
      }
//--- Add money to expert (will be deleted automatically))
   if(!ExtExpert.InitMoney(money))
      {
         //--- failed
         printf(__FUNCTION__+": error initializing money");
         ExtExpert.Deinit();
         return(INIT_FAILED);
      }
//--- Set money parameters
//--- Check all trading objects parameters
   if(!ExtExpert.ValidationSettings())
      {
         //--- failed
         ExtExpert.Deinit();
         return(INIT_FAILED);
      }
//--- Tuning of all necessary indicators
   if(!ExtExpert.InitIndicators())
      {
         //--- failed
         printf(__FUNCTION__+": error initializing indicators");
         ExtExpert.Deinit();
         return(INIT_FAILED);
      }
//--- ok
   return(INIT_SUCCEEDED);
}
//+------------------------------------------------------------------+
//| Deinitialization function of the expert                          |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
{
   ExtExpert.Deinit();
}
//+------------------------------------------------------------------+
//| "Tick" event handler function                                    |
//+------------------------------------------------------------------+
void OnTick()
{
   ExtExpert.OnTick();
}
//+------------------------------------------------------------------+
//| "Trade" event handler function                                   |
//+------------------------------------------------------------------+
void OnTrade()
{
   ExtExpert.OnTrade();
}
//+------------------------------------------------------------------+
//| "Timer" event handler function                                   |
//+------------------------------------------------------------------+
void OnTimer()
{
   ExtExpert.OnTimer();
}
//+------------------------------------------------------------------+
