//+------------------------------------------------------------------+
//|                                                test-cicustom.mq5 |
//|                             Thorsten Fischer Copyright 2019-2020 |
//|                                         https://mql5.tfsystem.de |
//+------------------------------------------------------------------+
#property copyright "Thorsten Fischer Copyright 2019-2020"
#property link      "https://mql5.tfsystem.de"
#property version   "1.00"
//+------------------------------------------------------------------+
//| Include                                                          |
//+------------------------------------------------------------------+
#include <Expert\Expert.mqh>
//--- available signals
#include <Expert\TF-Signale\SignalTFMA.mqh>
//--- available trailing
#include <Expert\Trailing\TrailingFixedPips.mqh>
//--- available money management
#include <Expert\Money\MoneyFixedLot.mqh>
//+------------------------------------------------------------------+
//| Inputs                                                           |
//+------------------------------------------------------------------+
//--- inputs for expert
input string         Expert_Title                  ="test-cicustom"; // Document name
ulong                Expert_MagicNumber            =123456789;           //
bool                 Expert_EveryTick              =false;           //
//--- inputs for main signal
input int            Signal_ThresholdOpen          =10;              // Signal threshold value to open [0...100]
input int            Signal_ThresholdClose         =10;              // Signal threshold value to close [0...100]
input double         Signal_PriceLevel             =0.0;             // Price level to execute a deal
input double         Signal_StopLevel              =50.0;            // Stop Loss level (in points)
input double         Signal_TakeLevel              =50.0;            // Take Profit level (in points)
input int            Signal_Expiration             =4;               // Expiration of pending orders (in bars)
input int            Signal_TFMA_PeriodFast        =13;              // TF-Test Moving Average(13,...) Period of fast MA
input ENUM_MA_METHOD Signal_TFMA_MethodFast        =MODE_SMA;         // TF-Test Moving Average(13,...) Method of fast MA
input int            Signal_TFMA_PeriodSlow        =21;              // TF-Test Moving Average(13,...) Period of slow MA
input ENUM_MA_METHOD Signal_TFMA_MethodSlow        =MODE_SMA;         // TF-Test Moving Average(13,...) Method of slow MA
input double         Signal_TFMA_Weight            =1.0;             // TF-Test Moving Average(13,...) Weight [0...1.0]
//--- inputs for trailing
input int            Trailing_FixedPips_StopLevel  =20;              // Stop Loss trailing level (in points)
input int            Trailing_FixedPips_ProfitLevel=20;              // Take Profit trailing level (in points)
//--- inputs for money
input double         Money_FixLot_Lots             =0.1;             // Fixed volume
//+------------------------------------------------------------------+
//| Global expert object                                             |
//+------------------------------------------------------------------+
CExpert ExtExpert;
//+------------------------------------------------------------------+
//| Initialization function of the expert                            |
//+------------------------------------------------------------------+
int OnInit()
{
//--- Initializing expert
   if(!ExtExpert.Init(Symbol(),Period(),Expert_EveryTick,Expert_MagicNumber))
      {
         //--- failed
         printf(__FUNCTION__+": error initializing expert");
         ExtExpert.Deinit();
         return(INIT_FAILED);
      }
//--- Creating signal
   CExpertSignal *signal=new CExpertSignal;
   if(signal==NULL)
      {
         //--- failed
         printf(__FUNCTION__+": error creating signal");
         ExtExpert.Deinit();
         return(INIT_FAILED);
      }
//---
   ExtExpert.InitSignal(signal);
   signal.ThresholdOpen(Signal_ThresholdOpen);
   signal.ThresholdClose(Signal_ThresholdClose);
   signal.PriceLevel(Signal_PriceLevel);
   signal.StopLevel(Signal_StopLevel);
   signal.TakeLevel(Signal_TakeLevel);
   signal.Expiration(Signal_Expiration);
//--- Creating filter CSignalTFMA
   CSignalTFMA *filter0=new CSignalTFMA;
   if(filter0==NULL)
      {
         //--- failed
         printf(__FUNCTION__+": error creating filter0");
         ExtExpert.Deinit();
         return(INIT_FAILED);
      }
   signal.AddFilter(filter0);
//--- Set filter parameters
   filter0.PeriodFast(Signal_TFMA_PeriodFast);
   filter0.MethodFast(Signal_TFMA_MethodFast);
   filter0.PeriodSlow(Signal_TFMA_PeriodSlow);
   filter0.MethodSlow(Signal_TFMA_MethodSlow);
   filter0.Weight(Signal_TFMA_Weight);
//--- Creation of trailing object
   CTrailingFixedPips *trailing=new CTrailingFixedPips;
   if(trailing==NULL)
      {
         //--- failed
         printf(__FUNCTION__+": error creating trailing");
         ExtExpert.Deinit();
         return(INIT_FAILED);
      }
//--- Add trailing to expert (will be deleted automatically))
   if(!ExtExpert.InitTrailing(trailing))
      {
         //--- failed
         printf(__FUNCTION__+": error initializing trailing");
         ExtExpert.Deinit();
         return(INIT_FAILED);
      }
//--- Set trailing parameters
   trailing.StopLevel(Trailing_FixedPips_StopLevel);
   trailing.ProfitLevel(Trailing_FixedPips_ProfitLevel);
//--- Creation of money object
   CMoneyFixedLot *money=new CMoneyFixedLot;
   if(money==NULL)
      {
         //--- failed
         printf(__FUNCTION__+": error creating money");
         ExtExpert.Deinit();
         return(INIT_FAILED);
      }
//--- Add money to expert (will be deleted automatically))
   if(!ExtExpert.InitMoney(money))
      {
         //--- failed
         printf(__FUNCTION__+": error initializing money");
         ExtExpert.Deinit();
         return(INIT_FAILED);
      }
//--- Set money parameters
   money.Lots(Money_FixLot_Lots);
//--- Check all trading objects parameters
   if(!ExtExpert.ValidationSettings())
      {
         //--- failed
         ExtExpert.Deinit();
         return(INIT_FAILED);
      }
//--- Tuning of all necessary indicators
   if(!ExtExpert.InitIndicators())
      {
         //--- failed
         printf(__FUNCTION__+": error initializing indicators");
         ExtExpert.Deinit();
         return(INIT_FAILED);
      }
//--- ok
   return(INIT_SUCCEEDED);
}
//+------------------------------------------------------------------+
//| Deinitialization function of the expert                          |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
{
   ExtExpert.Deinit();
}
//+------------------------------------------------------------------+
//| "Tick" event handler function                                    |
//+------------------------------------------------------------------+
void OnTick()
{
   ExtExpert.OnTick();
}
//+------------------------------------------------------------------+
//| "Trade" event handler function                                   |
//+------------------------------------------------------------------+
void OnTrade()
{
   ExtExpert.OnTrade();
}
//+------------------------------------------------------------------+
//| "Timer" event handler function                                   |
//+------------------------------------------------------------------+
void OnTimer()
{
   ExtExpert.OnTimer();
}
//+------------------------------------------------------------------+
