//+------------------------------------------------------------------+
//|                                                  tf-S1-T1-M1.mq5 |
//|                             Thorsten Fischer Copyright 2019-2020 |
//|                                         https://mql5.tfsystem.de |
//+------------------------------------------------------------------+
#property copyright "Thorsten Fischer Copyright 2019-2020"
#property link      "https://mql5.tfsystem.de"
#property version   "1.00"
//+------------------------------------------------------------------+
//| Include                                                          |
//+------------------------------------------------------------------+
#include <Expert\Expert.mqh>
//--- available signals
#include <Expert\Signal\SignalMA.mqh>
//--- available trailing
#include <Expert\Trailing\TrailingNone.mqh>
//--- available money management
#include <Expert\Money\MoneyFixedLot.mqh>
//+------------------------------------------------------------------+
//| Inputs                                                           |
//+------------------------------------------------------------------+
//--- inputs for expert
input string             Expert_Title         ="tf-S1-T1-M1"; // Document name
ulong                    Expert_MagicNumber   =13732;         //
bool                     Expert_EveryTick     =false;         //
//--- inputs for main signal
input int                Signal_ThresholdOpen =10;            // Signal threshold value to open [0...100]
input int                Signal_ThresholdClose=10;            // Signal threshold value to close [0...100]
input double             Signal_PriceLevel    =0.0;           // Price level to execute a deal
input double             Signal_StopLevel     =50.0;          // Stop Loss level (in points)
input double             Signal_TakeLevel     =50.0;          // Take Profit level (in points)
input int                Signal_Expiration    =4;             // Expiration of pending orders (in bars)
input int                Signal_0_MA_PeriodMA =5;             // Moving Average(5,0,...) Period of averaging
input int                Signal_0_MA_Shift    =0;             // Moving Average(5,0,...) Time shift
input ENUM_MA_METHOD     Signal_0_MA_Method   =MODE_SMMA;     // Moving Average(5,0,...) Method of averaging
input ENUM_APPLIED_PRICE Signal_0_MA_Applied  =PRICE_HIGH;    // Moving Average(5,0,...) Prices series
input double             Signal_0_MA_Weight   =1.0;           // Moving Average(5,0,...) Weight [0...1.0]
input int                Signal_1_MA_PeriodMA =5;             // Moving Average(5,0,...) Period of averaging
input int                Signal_1_MA_Shift    =0;             // Moving Average(5,0,...) Time shift
input ENUM_MA_METHOD     Signal_1_MA_Method   =MODE_SMMA;     // Moving Average(5,0,...) Method of averaging
input ENUM_APPLIED_PRICE Signal_1_MA_Applied  =PRICE_LOW;     // Moving Average(5,0,...) Prices series
input double             Signal_1_MA_Weight   =1.0;           // Moving Average(5,0,...) Weight [0...1.0]
//--- inputs for money
input double             Money_FixLot_Lots    =0.1;           // Fixed volume
//+------------------------------------------------------------------+
//| Global expert object                                             |
//+------------------------------------------------------------------+
CExpert ExtExpert;
//+------------------------------------------------------------------+
//| Initialization function of the expert                            |
//+------------------------------------------------------------------+
int OnInit()
{
//--- Initializing expert
   if(!ExtExpert.Init(Symbol(),PERIOD_M5,Expert_EveryTick,Expert_MagicNumber))
      {
         //--- failed
         printf(__FUNCTION__+": error initializing expert");
         ExtExpert.Deinit();
         return(INIT_FAILED);
      }
//--- Creating signal
   CExpertSignal *signal=new CExpertSignal;
   if(signal==NULL)
      {
         //--- failed
         printf(__FUNCTION__+": error creating signal");
         ExtExpert.Deinit();
         return(INIT_FAILED);
      }
//---
   ExtExpert.InitSignal(signal);
   signal.ThresholdOpen(Signal_ThresholdOpen);
   signal.ThresholdClose(Signal_ThresholdClose);
   signal.PriceLevel(Signal_PriceLevel);
   signal.StopLevel(Signal_StopLevel);
   signal.TakeLevel(Signal_TakeLevel);
   signal.Expiration(Signal_Expiration);
//--- Creating filter CSignalMA
   CSignalMA *filter0=new CSignalMA;
   if(filter0==NULL)
      {
         //--- failed
         printf(__FUNCTION__+": error creating filter0");
         ExtExpert.Deinit();
         return(INIT_FAILED);
      }
   signal.AddFilter(filter0);
//--- Set filter parameters
   filter0.PeriodMA(Signal_0_MA_PeriodMA);
   filter0.Shift(Signal_0_MA_Shift);
   filter0.Method(Signal_0_MA_Method);
   filter0.Applied(Signal_0_MA_Applied);
   filter0.Weight(Signal_0_MA_Weight);
//--- Creating filter CSignalMA
   CSignalMA *filter1=new CSignalMA;
   if(filter1==NULL)
      {
         //--- failed
         printf(__FUNCTION__+": error creating filter1");
         ExtExpert.Deinit();
         return(INIT_FAILED);
      }
   signal.AddFilter(filter1);
//--- Set filter parameters
   filter1.PeriodMA(Signal_1_MA_PeriodMA);
   filter1.Shift(Signal_1_MA_Shift);
   filter1.Method(Signal_1_MA_Method);
   filter1.Applied(Signal_1_MA_Applied);
   filter1.Weight(Signal_1_MA_Weight);
//--- Creation of trailing object
   CTrailingNone *trailing=new CTrailingNone;
   if(trailing==NULL)
      {
         //--- failed
         printf(__FUNCTION__+": error creating trailing");
         ExtExpert.Deinit();
         return(INIT_FAILED);
      }
//--- Add trailing to expert (will be deleted automatically))
   if(!ExtExpert.InitTrailing(trailing))
      {
         //--- failed
         printf(__FUNCTION__+": error initializing trailing");
         ExtExpert.Deinit();
         return(INIT_FAILED);
      }
//--- Set trailing parameters
//--- Creation of money object
   CMoneyFixedLot *money=new CMoneyFixedLot;
   if(money==NULL)
      {
         //--- failed
         printf(__FUNCTION__+": error creating money");
         ExtExpert.Deinit();
         return(INIT_FAILED);
      }
//--- Add money to expert (will be deleted automatically))
   if(!ExtExpert.InitMoney(money))
      {
         //--- failed
         printf(__FUNCTION__+": error initializing money");
         ExtExpert.Deinit();
         return(INIT_FAILED);
      }
//--- Set money parameters
   money.Lots(Money_FixLot_Lots);
//--- Check all trading objects parameters
   if(!ExtExpert.ValidationSettings())
      {
         //--- failed
         ExtExpert.Deinit();
         return(INIT_FAILED);
      }
//--- Tuning of all necessary indicators
   if(!ExtExpert.InitIndicators())
      {
         //--- failed
         printf(__FUNCTION__+": error initializing indicators");
         ExtExpert.Deinit();
         return(INIT_FAILED);
      }
//--- ok
   return(INIT_SUCCEEDED);
}
//+------------------------------------------------------------------+
//| Deinitialization function of the expert                          |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
{
   ExtExpert.Deinit();
}
//+------------------------------------------------------------------+
//| "Tick" event handler function                                    |
//+------------------------------------------------------------------+
void OnTick()
{
   ExtExpert.OnTick();
}
//+------------------------------------------------------------------+
//| "Trade" event handler function                                   |
//+------------------------------------------------------------------+
void OnTrade()
{
   ExtExpert.OnTrade();
}
//+------------------------------------------------------------------+
//| "Timer" event handler function                                   |
//+------------------------------------------------------------------+
void OnTimer()
{
   ExtExpert.OnTimer();
}
//+------------------------------------------------------------------+
